"""
This is the Continue configuration file.

See https://continue.dev/docs/customization to for documentation of the available options.
"""
import os
import sys

from continuedev.src.continuedev.core.models import Models
from continuedev.src.continuedev.core.config import (
    CustomCommand,
    SlashCommand,
    ContinueConfig,
)

from continuedev.src.continuedev.libs.llm.ollama import Ollama
from continuedev.src.continuedev.libs.llm.openai import OpenAI

from continuedev.src.continuedev.plugins.steps.open_config import OpenConfigStep
from continuedev.src.continuedev.plugins.steps.clear_history import ClearHistoryStep
from continuedev.src.continuedev.plugins.steps.feedback import FeedbackStep
from continuedev.src.continuedev.plugins.steps.comment_code import CommentCodeStep
from continuedev.src.continuedev.plugins.steps.share_session import ShareSessionStep
from continuedev.src.continuedev.plugins.steps.main import EditHighlightedCodeStep

from continuedev.src.continuedev.plugins.context_providers.search import (
    SearchContextProvider,
)
from continuedev.src.continuedev.plugins.context_providers.diff import (
    DiffContextProvider,
)
from continuedev.src.continuedev.plugins.context_providers.url import URLContextProvider
from continuedev.src.continuedev.plugins.context_providers.terminal import (
    TerminalContextProvider,
)

from dotenv import dotenv_values
from continuedev.src.continuedev.libs.util.paths import getGlobalFolderPath
from continuedev.src.continuedev.libs.util.logging import logger

logger.info(f"sys.version: {sys.version}")
c = dotenv_values(getGlobalFolderPath() + "/.env")
for path in c.get("SYS_PATH", "").split(","):
    if path != "":
        abspath = os.path.abspath(path.strip())
        if abspath not in sys.path:
            sys.path.append(abspath)
            logger.info(f"Added {abspath} to system path")
logger.info(f"sys.path: {', '.join(sys.path)}")

from jira_context_provider import JIRAContextProvider
from confluence_context_provider import ConfluenceContextProvider
from gitlab_context_provider import GitLabContextProvider

config = ContinueConfig(
    allow_anonymous_telemetry=False,
    models=Models(
        default=Ollama(context_length=4096, model="codellama"),
        unused=[
            Ollama(context_length=4096, model="codellama:7b-code"),
            Ollama(context_length=4096, model="codellama:7b-python"),
            Ollama(context_length=4096, model="codellama:13b"),
            OpenAI(model="gpt-3.5-turbo", api_key=c.get("OPENAI_API_KEY")),
            OpenAI(model="gpt-3.5-turbo-16k", api_key=c.get("OPENAI_API_KEY")),
            OpenAI(model="gpt-4", api_key=c.get("OPENAI_API_KEY")),
            OpenAI(model="gpt-4-32k", api_key=c.get("OPENAI_API_KEY")),
        ],
    ),
    system_message=None,
    temperature=0.3,
    custom_commands=[
        CustomCommand(
            name="test",
            description="Write unit tests for the higlighted code",
            prompt="Write a comprehensive set of unit tests for the selected code. It should setup, run tests that check for correctness including important edge cases, and teardown. Ensure that the tests are complete and sophisticated. Give the tests just as chat output, don't edit any file.",
        )
    ],
    slash_commands=[
        SlashCommand(
            name="edit",
            description="Edit code in the current file or the highlighted code",
            step=EditHighlightedCodeStep,
        ),
        SlashCommand(
            name="config",
            description="Customize Continue - slash commands, LLMs, system message, etc.",
            step=OpenConfigStep,
        ),
        SlashCommand(
            name="comment",
            description="Write comments for the current file or highlighted code",
            step=CommentCodeStep,
        ),
        SlashCommand(
            name="feedback",
            description="Send feedback to improve Continue",
            step=FeedbackStep,
        ),
        SlashCommand(
            name="clear",
            description="Clear step history",
            step=ClearHistoryStep,
        ),
        SlashCommand(
            name="share",
            description="Download and share the session transcript",
            step=ShareSessionStep,
        ),
    ],
    context_providers=[
        SearchContextProvider(),
        DiffContextProvider(),
        URLContextProvider(
            preset_urls=[
                # Add any common urls you reference here so they appear in autocomplete
            ]
        ),
        TerminalContextProvider(),
        JIRAContextProvider(
            server=c.get("JIRA_SERVER"),
            username=c.get("JIRA_USERNAME"),
            token=c.get("JIRA_TOKEN"),
        ),
        ConfluenceContextProvider(
            server=c.get("CONFLUENCE_SERVER"),
            username=c.get("CONFLUENCE_USERNAME"),
            token=c.get("CONFLUENCE_TOKEN"),
        ),
        GitLabContextProvider(
            server=c.get("GITLAB_SERVER"),
            token=c.get("GITLAB_TOKEN"),
        ),
    ],
)
